==> apache-cxf-3.1.18-src.zip: apache-cxf-3.1.18-src/systests/cdi/base/src/main/java/org/apache/cxf/systests/cdi/base/BookStoreByIds.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systests.cdi.base;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;

@ApplicationScoped
@Path("/bookstore/byIds")
public class BookStoreByIds {
    @Inject
    private BookStoreService service;
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public Collection< Book > getBooks(@QueryParam("ids") List< String > ids) {
        final Collection<Book> books = new ArrayList<Book>();
        
        for (final String id: ids) {
            final Book book = service.get(id);
            if (book != null) {
                books.add(book);
            }
        }
        
        return books;
    }
}

==> apache-cxf-3.6.7-src.zip: apache-cxf-3.6.7-src/systests/cdi/base/src/main/java/org/apache/cxf/systests/cdi/base/BookStoreByIds.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systests.cdi.base;

import java.util.Collection;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;

@ApplicationScoped
@Path("/bookstore/byIds")
public class BookStoreByIds {
    @Inject
    private BookStoreService service;
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public Collection< Book > getBooks(@QueryParam("ids") List< String > ids) {
        return ids.stream().map(service::get).distinct().filter(Objects::nonNull).collect(Collectors.toList());
    }
}
